@@ -6,6 +6,7 @@ https://github.com/agoragames/torus/blob/master/LICENSE.txt
 
 import imp
 import hashlib
+import logging
 
 from torus.schema import Schema, long_or_float
 from torus.aggregates import Aggregates
@@ -32,7 +33,7 @@ class Configuration(object):
     Load a file and cache the rename for future reloading.
     '''
     self._files.append( fname )
-    self._load_source( fname )
+    self._load_source( fname, notify='on_load' )
 
   def reload(self):
     '''
@@ -45,7 +46,7 @@ class Configuration(object):
     self._macros = {}
     
     for fname in self._files:
-      self._load_source( fname )
+      self._load_source( fname, notify='on_reload' )
 
   def transform(self, name):
     '''
@@ -96,15 +97,15 @@ class Configuration(object):
       stored = schema.store(stat, val, timestamp)
       if self._debug:
         if stored:
-          print 'STOR', stat, val, timestamp
+          logging.debug('STOR %s %s %.06f'%(stat, val, timestamp))
         elif self._debug > 1:
-          print 'SKIP', stat, val, timestamp
+          logging.debug('SKIP %s %s %.06f'%(stat, val, timestamp))
     
     # Infinite loop is prevented by match() implementation
     for ag in aggregates:
       processed = self.process(ag, val, timestamp, seen=seen)
       if self._debug and processed:
-        print 'AGRT', ag, 'FROM', stat, val, timestamp
+        logging.debug('AGRT %s FROM %s %s %.06f'%(ag, stat, val, timestamp))
 
     return True
 
@@ -114,7 +115,7 @@ class Configuration(object):
   def load_aggregate(self, spec):
     self._aggregates.add( spec )
 
-  def _load_source(self, fname):
+  def _load_source(self, fname, notify='on_load'):
     '''
     Load the file source.
     '''
@@ -139,3 +140,6 @@ class Configuration(object):
         self._macros[name] = macro
       
       self._debug = getattr(mod, 'DEBUG', self._debug)
+
+      if callable( getattr(mod, notify, None) ):
+        getattr(mod, notify)()
